LittleFishPrinterManager class
Constructors
Properties
- core ↔ LittleFishCore
-
getter/setter pair
- databaseClient → DatabaseClient?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- logger → LoggerService
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPrinter<
T extends LittleFishPrinter> () → LittleFishPrinter? -
getPrinterByType(
PrinterType type) → LittleFishPrinter? -
getPrinters(
) → List< LittleFishPrinter> -
getSpecificPrinter<
T extends LittleFishPrinter> () → LittleFishPrinter? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setupPrinter(
LittleFishPrinter printer) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited